@@ -21,6 +21,11 @@ from pm4py.algo.discovery.inductive.variants.im_clean import algorithm as im_cle
 from pm4py.algo.discovery.inductive.variants.im_d import dfg_based
 from pm4py.algo.discovery.inductive.variants.im_f import algorithm as im_f_algo
 from pm4py.util import exec_utils
+from typing import Optional, Dict, Any, Union, Tuple, List
+from pm4py.objects.log.obj import EventLog, EventStream
+import pandas as pd
+from pm4py.objects.petri_net.obj import PetriNet, Marking
+from pm4py.objects.process_tree.obj import ProcessTree
 
 
 class Variants(Enum):
@@ -42,7 +47,7 @@ DEFAULT_VARIANT_VARIANTS = IM_CLEAN
 DEFAULT_VARIANT_DFG = IMd
 
 
-def apply(log, parameters=None, variant=DEFAULT_VARIANT_LOG):
+def apply(log: Union[EventLog, EventStream, pd.DataFrame], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_LOG) -> Tuple[PetriNet, Marking, Marking]:
     """
     Apply the chosen IM algorithm to a log obtaining a Petri net along with an initial and final marking
 
@@ -70,7 +75,7 @@ def apply(log, parameters=None, variant=DEFAULT_VARIANT_LOG):
     return exec_utils.get_variant(variant).apply(log, parameters=parameters)
 
 
-def apply_dfg(dfg, parameters=None, variant=DEFAULT_VARIANT_DFG):
+def apply_dfg(dfg: Dict[Tuple[str, str], int], parameters=None, variant=DEFAULT_VARIANT_DFG) -> Tuple[PetriNet, Marking, Marking]:
     """
     Apply the chosen IM algorithm to a DFG graph obtaining a Petri net along with an initial and final marking
 
@@ -98,7 +103,7 @@ def apply_dfg(dfg, parameters=None, variant=DEFAULT_VARIANT_DFG):
     return exec_utils.get_variant(variant).apply_dfg(dfg, parameters=parameters)
 
 
-def apply_tree(log, parameters=None, variant=DEFAULT_VARIANT_LOG):
+def apply_tree(log: Union[EventLog, EventStream, pd.DataFrame], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_LOG) -> ProcessTree:
     """
     Apply the chosen IM algorithm to a log obtaining a process tree
 
@@ -122,7 +127,7 @@ def apply_tree(log, parameters=None, variant=DEFAULT_VARIANT_LOG):
     return exec_utils.get_variant(variant).apply_tree(log, parameters=parameters)
 
 
-def apply_tree_dfg(dfg, parameters=None, variant=DEFAULT_VARIANT_DFG):
+def apply_tree_dfg(dfg: Dict[Tuple[str, str], int], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_DFG) -> ProcessTree:
     """
     Apply the chosen IM algorithm to a DFG graph obtaining a process tree
 
@@ -146,7 +151,7 @@ def apply_tree_dfg(dfg, parameters=None, variant=DEFAULT_VARIANT_DFG):
     return exec_utils.get_variant(variant).apply_tree_dfg(dfg, parameters=parameters)
 
 
-def apply_variants(variants, parameters=None, variant=DEFAULT_VARIANT_VARIANTS):
+def apply_variants(variants: Dict[Union[str, List[str]], int], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_VARIANTS) -> Tuple[PetriNet, Marking, Marking]:
     """
     Apply the chosen IM algorithm to a dictionary/list/set of variants obtaining a Petri net along with an initial and final marking
 
@@ -174,7 +179,7 @@ def apply_variants(variants, parameters=None, variant=DEFAULT_VARIANT_VARIANTS):
     return exec_utils.get_variant(variant).apply_variants(variants, parameters=parameters)
 
 
-def apply_tree_variants(variants, parameters=None, variant=DEFAULT_VARIANT_VARIANTS):
+def apply_tree_variants(variants: Dict[Union[str, List[str]], int], parameters: Optional[Dict[Any, Any]] = None, variant=DEFAULT_VARIANT_VARIANTS) -> ProcessTree:
     """
     Apply the chosen IM algorithm to a dictionary/list/set of variants a log obtaining a process tree
 
