@@ -14,4 +14,4 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.algo.transformation import log_to_trie
+from pm4py.algo.transformation import log_to_trie, log_to_features
