@@ -14,7 +14,7 @@
     You should have received a copy of the GNU General Public License
     along with PM4Py.  If not, see <https://www.gnu.org/licenses/>.
 '''
-from pm4py.objects.petri.petrinet import Marking
+from pm4py.objects.petri.obj import Marking
 
 
 def discover_final_marking(petri):
