@@ -28,6 +28,12 @@ from pm4py.statistics.sojourn_time.log import get as soj_time_get
 from enum import Enum
 from pm4py.util import constants
 
+from typing import Optional, Dict, Any, Union, Tuple
+from pm4py.objects.log.obj import EventLog, EventStream
+from pm4py.util import typing
+import graphviz
+from pm4py.objects.log.obj import EventLog
+
 
 class Parameters(Enum):
     ACTIVITY_KEY = constants.PARAMETER_CONSTANT_ACTIVITY_KEY
@@ -38,6 +44,7 @@ class Parameters(Enum):
     TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_TIMESTAMP_KEY
     START_TIMESTAMP_KEY = constants.PARAMETER_CONSTANT_START_TIMESTAMP_KEY
     FONT_SIZE = "font_size"
+    AGGREGATION_MEASURE = "aggregation_measure"
 
 
 def get_min_max_value(dfg):
@@ -240,7 +247,28 @@ def graphviz_visualization(activities_count, dfg, image_format="png", measure="f
     return viz
 
 
-def apply(dfg, log=None, parameters=None, activities_count=None, soj_time=None):
+def apply(dfg: Dict[Tuple[str, str], int], log: EventLog = None, parameters: Optional[Dict[Any, Any]] = None, activities_count : Dict[str, int] = None, soj_time: Dict[str, float] = None) -> graphviz.Digraph:
+    """
+    Visualize a performance directly-follows graph
+
+    Parameters
+    -----------------
+    dfg
+        Performance Directly-follows graph
+    log
+        (if provided) Event log for the calculation of statistics
+    activities_count
+        (if provided) Dictionary associating to each activity the number of occurrences in the log.
+    soj_time
+        (if provided) Dictionary associating to each activity the average sojourn time
+    parameters
+        Variant-specific parameters
+
+    Returns
+    -----------------
+    gviz
+        Graphviz digraph
+    """
     if parameters is None:
         parameters = {}
 
@@ -252,6 +280,7 @@ def apply(dfg, log=None, parameters=None, activities_count=None, soj_time=None):
     font_size = exec_utils.get_param_value(Parameters.FONT_SIZE, parameters, 12)
     font_size = str(font_size)
     activities = dfg_utils.get_activities_from_dfg(dfg)
+    aggregation_measure = exec_utils.get_param_value(Parameters.AGGREGATION_MEASURE, parameters, "mean")
 
     if activities_count is None:
         if log is not None:
@@ -265,6 +294,19 @@ def apply(dfg, log=None, parameters=None, activities_count=None, soj_time=None):
         else:
             soj_time = {key: 0 for key in activities}
 
+    # if all the aggregation measures are provided for a given key,
+    # then pick one of the values for the representation
+    dfg0 = dfg
+    dfg = {}
+    for key in dfg0:
+        try:
+            if aggregation_measure in dfg0[key]:
+                dfg[key] = dfg0[key][aggregation_measure]
+            else:
+                dfg[key] = dfg0[key]
+        except:
+            dfg[key] = dfg0[key]
+
     return graphviz_visualization(activities_count, dfg, image_format=image_format, measure="performance",
                                   max_no_of_edges_in_diagram=max_no_of_edges_in_diagram,
                                   start_activities=start_activities, end_activities=end_activities, soj_time=soj_time,
